@@ -4,18 +4,20 @@ from typing import List
 from vortex.Tuple import addTupleType, TupleField, Tuple
 
 from peek_plugin_graphdb._private.PluginNames import graphDbTuplePrefix
-from peek_plugin_graphdb.tuples.GraphDbTraceConfigRuleTuple import \
-    GraphDbTraceConfigRuleTuple
+from peek_plugin_graphdb.tuples.GraphDbTraceConfigRuleTuple import (
+    GraphDbTraceConfigRuleTuple,
+)
 
 
 @addTupleType
 class GraphDbTraceConfigTuple(Tuple):
-    """ TraceConfig Tuple
+    """TraceConfig Tuple
 
     This tuple is the publicly exposed TraceConfig
 
     """
-    __tupleType__ = graphDbTuplePrefix + 'GraphDbTraceConfigTuple'
+
+    __tupleType__ = graphDbTuplePrefix + "GraphDbTraceConfigTuple"
 
     #:  The model set of this segment [Required]
     modelSetKey: str = TupleField()
